@@ -18,9 +18,8 @@
 #include "ka-plugin-dummy.h"
 #include <gmodule.h>
 
-G_DEFINE_TYPE (KaPluginDummy, ka_plugin_dummy, KA_TYPE_PLUGIN)
-#define GET_PRIVATE(o) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((o), KA_TYPE_PLUGIN_DUMMY, KaPluginDummyPrivate))
+/* Plugin entry point */
+G_MODULE_EXPORT KaPlugin *ka_plugin_create (void);
 
 int ka_plugin_major_version = KA_PLUGIN_MAJOR_VERSION;
 int ka_plugin_minor_version = KA_PLUGIN_MINOR_VERSION;
@@ -31,16 +30,16 @@ ka_plugin_create (void)
     return KA_PLUGIN (ka_plugin_dummy_new ());
 }
 
-typedef struct _KaPluginDummyPrivate KaPluginDummyPrivate;
-
-struct _KaPluginDummyPrivate {
+typedef struct _KaPluginDummyPrivate {
     gulong handlers[3];
-};
+} KaPluginDummyPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (KaPluginDummy, ka_plugin_dummy, KA_TYPE_PLUGIN)
 
 static void
 event_cb (gpointer *applet, gchar *princ, guint when, gpointer user_data)
 {
-    g_message ("%s %s @%d", user_data, princ, when);
+    g_message ("%s %s @%d", (gchar*)user_data, princ, when);
 }
 
 static void
@@ -52,7 +51,7 @@ ka_plugin_dummy_finalize (GObject *object)
 static void
 ka_plugin_dummy_activate (KaPlugin *self, KaApplet *applet)
 {
-    KaPluginDummyPrivate *priv = GET_PRIVATE (self);
+    KaPluginDummyPrivate *priv = ka_plugin_dummy_get_instance_private (KA_PLUGIN_DUMMY (self));
 
     priv->handlers[0] = g_signal_connect (applet,
                                           "krb-tgt-expired",
@@ -69,7 +68,7 @@ static void
 ka_plugin_dummy_deactivate (KaPlugin *self, KaApplet *applet)
 {
     int i;
-    KaPluginDummyPrivate *priv = GET_PRIVATE (self);
+    KaPluginDummyPrivate *priv = ka_plugin_dummy_get_instance_private (KA_PLUGIN_DUMMY (self));
 
     for (i = 0; i < G_N_ELEMENTS (priv->handlers); i++)
         g_signal_handler_disconnect (applet, priv->handlers[i]);
@@ -81,8 +80,6 @@ ka_plugin_dummy_class_init (KaPluginDummyClass *klass)
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
     KaPluginClass *plugin_class = KA_PLUGIN_CLASS (klass);
 
-    g_type_class_add_private (klass, sizeof (KaPluginDummyPrivate));
-
     plugin_class->activate = ka_plugin_dummy_activate;
     plugin_class->deactivate = ka_plugin_dummy_deactivate;
     object_class->finalize = ka_plugin_dummy_finalize;
