@@ -1,6 +1,6 @@
 /* Krb5 Auth Applet -- Acquire and release Kerberos tickets
  *
- * (C) 2008,2009,2010,2013 Guido Guenther <agx@sigxcpu.org>
+ * (C) 2008,2009,2010,2013,2021 Guido Guenther <agx@sigxcpu.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,6 @@
 #include "ka-plugin-loader.h"
 #include "ka-preferences.h"
 #include "ka-closures.h"
-#include <libnotify/notify.h>
 
 #include <signal.h>
 
@@ -55,13 +54,6 @@ enum {
 };
 
 
-enum {
-    KA_DEBUG_NO_APP_MENU    = 1,  /* Disable gtk-shell-shows-app-menu gtk setting */
-    KA_DEBUG_NO_HEADER_BAR  = 2,  /* Disable header-bar setting */
-    KA_DEBUG_NO_PERSISTENCE = 4,  /* notification system does not support persistence */
-};
-
-
 const gchar *ka_signal_names[KA_SIGNAL_COUNT] = {
     "krb-tgt-acquired",
     "krb-tgt-renewed",
@@ -82,13 +74,8 @@ struct _KaAppletClass {
     guint signals[KA_SIGNAL_COUNT];
 };
 
-G_DEFINE_TYPE (KaApplet, ka_applet, GTK_TYPE_APPLICATION);
-
 struct _KaAppletPrivate {
-    GtkStatusIcon *tray_icon;   /* the tray icon */
-    GtkWidget *context_menu;    /* the tray icon's context menu */
     const char *icons[3];       /* for invalid, expiring and valid tickts */
-    gboolean ns_persistence;    /* does the notification server support persistence */
 
     KaPwDialog *pwdialog;       /* the password dialog */
     KaPreferences *prefs;       /* the prefs dialog */
@@ -100,7 +87,6 @@ struct _KaAppletPrivate {
     gboolean auto_run;          /* only start with valid ccache */
     gint debug_flags;           /* Debug options from environment */
 
-    NotifyNotification *notification;   /* notification messages */
     char *krb_msg;              /* Additional banner delivered by Kerberos */
 
     /* GSettings options */
@@ -117,8 +103,8 @@ struct _KaAppletPrivate {
     GSettings *settings;         /* GSettings client */
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (KaApplet, ka_applet, GTK_TYPE_APPLICATION);
 
-static void ka_close_notification (KaApplet *self);
 static gboolean is_initialized;
 
 static void
@@ -174,10 +160,8 @@ ka_applet_local_command_line (GApplication *application,
     };
 
     KA_DEBUG ("Parsing local command line");
-#if GLIB_CHECK_VERSION(2, 40, 0)
     flags = g_application_get_flags(application);
     g_application_set_flags(application, flags | G_APPLICATION_HANDLES_COMMAND_LINE);
-#endif
 
     context = g_option_context_new ("- Kerberos 5 credential checking");
     g_option_context_add_main_entries (context, options, NULL);
@@ -197,6 +181,7 @@ ka_applet_local_command_line (GApplication *application,
     return FALSE;
 }
 
+
 GtkWindow *ka_applet_last_focused_window (KaApplet *self)
 {
     GList *l = gtk_application_get_windows (GTK_APPLICATION(self));
@@ -208,26 +193,6 @@ GtkWindow *ka_applet_last_focused_window (KaApplet *self)
 }
 
 
-static void
-action_remove_credentials_cache (GSimpleAction *action G_GNUC_UNUSED,
-                                 GVariant *parameter G_GNUC_UNUSED,
-                                 gpointer userdata)
-{
-    KaApplet *self = userdata;
-    ka_destroy_ccache (self);
-}
-
-
-static void
-action_list_tickets (GSimpleAction *action G_GNUC_UNUSED,
-                     GVariant *parameter G_GNUC_UNUSED,
-                     gpointer userdata)
-{
-    KaApplet *self = userdata;
-    ka_main_window_show (self);
-}
-
-
 static void
 action_preferences (GSimpleAction *action G_GNUC_UNUSED,
 		    GVariant *parameter G_GNUC_UNUSED,
@@ -293,37 +258,24 @@ setup_signal_handlers (KaApplet *applet)
 
 
 static void
-ka_applet_handle_debug(KaApplet *self)
+ka_remove_ccache_action (GSimpleAction *action G_GNUC_UNUSED,
+                         GVariant *parameter G_GNUC_UNUSED,
+                         gpointer userdata)
 {
-    const gchar* debug;
-    gchar **debug_opts, **opt;
+    KaApplet *self = KA_APPLET (userdata);
+    KA_DEBUG ("Removing ccache");
+    ka_destroy_ccache (self);
+}
 
-    debug = g_getenv ("KRB5_AUTH_DIALOG_DEBUG");
-    if (!debug)
-        return;
 
-    debug_opts = g_strsplit(debug, ",", -1);
-    for (opt = debug_opts; *opt != NULL; opt++) {
-        if (!g_strcmp0(*opt, "no-app-menu")) {
-            KA_DEBUG ("Disabling app menu Gtk setting as requested...");
-            g_object_set (gtk_settings_get_default (),
-                          "gtk-shell-shows-app-menu", FALSE,
-                          NULL);
-            self->priv->debug_flags |= KA_DEBUG_NO_APP_MENU;
-        } else if (!g_strcmp0(*opt, "no-header-bar")) {
-            KA_DEBUG ("Disabling use-header-bar Gtk setting  as requested...");
-            g_object_set (gtk_settings_get_default (),
-                          "gtk-dialogs-use-header", FALSE,
-                          NULL);
-            self->priv->debug_flags |= KA_DEBUG_NO_HEADER_BAR;
-        } else if (!g_strcmp0(*opt, "no-persistence")) {
-            self->priv->debug_flags |= KA_DEBUG_NO_PERSISTENCE;
-        } else {
-            g_warning ("Unhandled debug options %s", *opt);
-        }
-    }
-
-    g_strfreev (debug_opts);
+static void
+ka_acquire_tgt_action (GSimpleAction *action G_GNUC_UNUSED,
+                       GVariant *parameter G_GNUC_UNUSED,
+                       gpointer userdata)
+{
+    KaApplet *self = KA_APPLET (userdata);
+    KA_DEBUG ("Getting new tgt");
+    ka_grab_credentials (self);
 }
 
 
@@ -332,30 +284,11 @@ static GActionEntry app_entries[] = {
     { "about", action_about, NULL, NULL, NULL, {0} },
     { "help", action_help, NULL, NULL, NULL, {0} },
     { "quit", action_quit, NULL, NULL, NULL, {0} },
+    { "acquire-ticket", ka_acquire_tgt_action , NULL, NULL, NULL, {0} },
+    { "remove-ccache", ka_remove_ccache_action , NULL, NULL, NULL, {0} },
 };
 
 
-static void
-ka_applet_app_menu_create(KaApplet *self)
-
-{
-    GMenuModel *app_menu;
-    GtkBuilder *builder;
-
-    builder = gtk_builder_new_from_resource ("/org/gnome/krb5-auth-dialog/ui/app-menu.ui");
-    app_menu = G_MENU_MODEL (gtk_builder_get_object (builder, "app-menu"));
-
-    g_action_map_add_action_entries (G_ACTION_MAP (self),
-                                     app_entries, G_N_ELEMENTS (app_entries),
-                                     self);
-
-    g_assert (app_menu != NULL);
-    gtk_application_set_app_menu (GTK_APPLICATION(self),
-                                  app_menu);
-
-    g_object_unref (builder);
-}
-
 static void
 ka_applet_startup (GApplication *application)
 {
@@ -373,7 +306,9 @@ ka_applet_startup (GApplication *application)
 
     self->priv->prefs = ka_preferences_new (self);
 
-    ka_applet_app_menu_create(self);
+    g_action_map_add_action_entries (G_ACTION_MAP (self),
+                                     app_entries, G_N_ELEMENTS (app_entries),
+                                     self);
 }
 
 static void
@@ -493,12 +428,6 @@ ka_applet_dispose (GObject *object)
     KaApplet *applet = KA_APPLET (object);
     GObjectClass *parent_class = G_OBJECT_CLASS (ka_applet_parent_class);
 
-    ka_close_notification (applet);
-
-    if (applet->priv->tray_icon) {
-        g_object_unref (applet->priv->tray_icon);
-        applet->priv->tray_icon = NULL;
-    }
     if (applet->priv->pwdialog) {
         gtk_widget_destroy (GTK_WIDGET(applet->priv->pwdialog));
         applet->priv->pwdialog = NULL;
@@ -508,8 +437,7 @@ ka_applet_dispose (GObject *object)
         applet->priv->loader = NULL;
     }
 
-    if (parent_class->dispose != NULL)
-        parent_class->dispose (object);
+    parent_class->dispose (object);
 }
 
 
@@ -525,16 +453,13 @@ ka_applet_finalize (GObject *object)
     g_free (applet->priv->krb_msg);
     /* no need to free applet->priv */
 
-    if (parent_class->finalize != NULL)
-        parent_class->finalize (object);
+    parent_class->finalize (object);
 }
 
 static void
 ka_applet_init (KaApplet *applet)
 {
-    applet->priv = G_TYPE_INSTANCE_GET_PRIVATE (applet,
-                                                KA_TYPE_APPLET,
-                                                KaAppletPrivate);
+    applet->priv = ka_applet_get_instance_private (applet);
 }
 
 static void
@@ -546,12 +471,12 @@ ka_applet_class_init (KaAppletClass *klass)
 
     object_class->dispose = ka_applet_dispose;
     object_class->finalize = ka_applet_finalize;
-    g_type_class_add_private (klass, sizeof (KaAppletPrivate));
 
     G_APPLICATION_CLASS (klass)->local_command_line =   \
         ka_applet_local_command_line;
     G_APPLICATION_CLASS (klass)->command_line = ka_applet_command_line;
     G_APPLICATION_CLASS (klass)->startup = ka_applet_startup;
+    G_APPLICATION_CLASS (klass)->activate = ka_applet_activate;
 
     object_class->set_property = ka_applet_set_property;
     object_class->get_property = ka_applet_get_property;
@@ -637,7 +562,7 @@ static KaApplet *
 ka_applet_new (void)
 {
     return g_object_new (KA_TYPE_APPLET,
-                         "application-id", "org.gnome.KrbAuthDialog",
+                         "application-id", KA_APP_ID,
                          NULL);
 }
 
@@ -671,221 +596,40 @@ ka_applet_tooltip_text (int remaining)
 }
 
 
-/* determine the current icon */
-static const char *
-ka_applet_select_icon (KaApplet *applet, int remaining)
-{
-    enum ka_icon status_icon = inv_icon;
-
-    if (remaining > 0) {
-        if (remaining < applet->priv->pw_prompt_secs &&
-            !applet->priv->renewable)
-            status_icon = exp_icon;
-        else
-            status_icon = val_icon;
-    }
-
-    return applet->priv->icons[status_icon];
-}
-
-
-static gboolean
-ka_tray_icon_is_embedded (KaApplet *self)
-{
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-    if (self->priv->tray_icon
-        && gtk_status_icon_is_embedded (self->priv->tray_icon))
-        return TRUE;
-    else
-        return FALSE;
-G_GNUC_END_IGNORE_DEPRECATIONS
-}
-
-
-static gboolean
-ka_show_notification (KaApplet *applet)
-{
-    /* wait for the panel to be settled before showing a bubble */
-    if (applet->priv->ns_persistence
-        || ka_tray_icon_is_embedded (applet)) {
-        GError *error = NULL;
-        gboolean ret;
-
-        ret = notify_notification_show (applet->priv->notification, &error);
-        if (!ret) {
-            g_assert (error);
-            g_assert (error->message);
-            g_warning ("Failed to show notification: %s", error->message);
-            g_clear_error (&error);
-        }
-    } else {
-        g_timeout_add_seconds (5, (GSourceFunc) ka_show_notification, applet);
-    }
-    return FALSE;
-}
-
-
-/* Callback to handle disabling of notification */
-static void
-ka_notify_disable_action_cb (NotifyNotification *notification G_GNUC_UNUSED,
-                              gchar *action,
-                              gpointer user_data)
-{
-    KaApplet *self = KA_APPLET (user_data);
-    GSettings *ns = g_settings_get_child (self->priv->settings,
-                                              KA_SETTING_CHILD_NOTIFY);
-
-    if (strcmp (action, "dont-show-again") == 0) {
-        KA_DEBUG ("turning of notification %s", self->priv->notify_key);
-        if (!g_settings_set_boolean (ns,
-                                     self->priv->notify_key, FALSE)) {
-            g_warning("Failed to set %s", self->priv->notify_key);
-        }
-        self->priv->notify_key = NULL;
-    } else {
-        g_warning ("unkonwn action for callback");
-    }
-    g_object_unref (ns);
-}
-
-
-/* Callback to handle ticket related actions */
-static void
-ka_notify_ticket_action_cb (NotifyNotification *notification G_GNUC_UNUSED,
-                            gchar *action,
-                            gpointer user_data)
-{
-    KaApplet *self = KA_APPLET (user_data);
-
-    g_return_if_fail (self != NULL);
-
-    if (strcmp (action, "ka-acquire-tgt") == 0) {
-        KA_DEBUG ("Getting new tgt");
-        ka_grab_credentials (self);
-    } else if (strcmp (action, "ka-remove-ccache") == 0) {
-        KA_DEBUG ("Removing ccache");
-        ka_destroy_ccache (self);
-    } else if (strcmp (action, "ka-list-tickets") == 0) {
-        KA_DEBUG ("Showing main window");
-        ka_main_window_show (self);
-    } else {
-        g_warning ("unkonwn action for callback");
-    }
-}
-
-
-static void
-ka_close_notification (KaApplet *self)
-{
-    GError *error = NULL;
-
-    if (self->priv->notification != NULL) {
-        if (!notify_notification_close (self->priv->notification, &error)) {
-            if (error)
-                g_warning ("Cannot close notification %s", error->message);
-            else
-                g_warning ("Cannot close notification");
-        }
-        g_object_unref (self->priv->notification);
-        g_clear_error (&error);
-        self->priv->notification = NULL;
-    }
-}
-
 static void
 ka_send_event_notification (KaApplet *self,
                             const char *summary,
                             const char *message,
-                            const char *icon,
+                            const char *iconname,
                             gboolean get_ticket_action)
 {
-    NotifyNotification *notification;
-    const char *hint;
-    gint timeout;
+    g_autoptr (GNotification) notification = NULL;
+    /* TODO: ka_appliet_select_icon ? */
+    g_autoptr (GIcon) icon = g_icon_new_for_string (iconname, NULL);
 
     g_return_if_fail (self != NULL);
     g_return_if_fail (summary != NULL);
     g_return_if_fail (message != NULL);
 
-    if (!notify_is_initted ())
-        notify_init (KA_NAME);
+    notification = g_notification_new (summary);
+    g_notification_set_body (notification, message);
+    g_notification_set_icon (notification, icon);
 
-    if (self->priv->notification) {
-        notification = self->priv->notification;
-        notify_notification_update (notification, summary, message, icon);
-    } else {
-        notification = self->priv->notification =
-            notify_notification_new (summary, message, icon);
-        notify_notification_set_urgency (notification, NOTIFY_URGENCY_NORMAL);
-    }
+    if (get_ticket_action)
+        g_notification_add_button (notification,
+                                   _("Get Ticket"),
+                                   "app.acquire-ticket");
+    else
+        g_notification_add_button (notification,
+                                   _("Remove Credentials Cache"),
+                                   "app.remove-ccache");
 
-    notify_notification_set_hint (notification,
-                                  "desktop-entry",
-                                  g_variant_new_string (PACKAGE));
-    if (self->priv->ns_persistence) {
-        hint = "resident";
-        timeout = NOTIFY_EXPIRES_NEVER;
-
-        notify_notification_set_timeout (notification, timeout);
-        notify_notification_clear_hints (notification);
-        notify_notification_set_hint (notification,
-                                      hint,
-                                      g_variant_new_boolean (TRUE));
-    }
-
-    notify_notification_clear_actions(notification);
-
-    if (self->priv->ns_persistence) {
-        notify_notification_add_action (notification,
-                                        "ka-list-tickets",
-                                        _("List Tickets"),
-                                        (NotifyActionCallback)
-                                        ka_notify_ticket_action_cb,
-                                        self,
-                                        NULL);
-    }
-
-    if (get_ticket_action) {
-        notify_notification_add_action (notification,
-                                        "ka-acquire-tgt",
-                                        _("Get Ticket"),
-                                        (NotifyActionCallback)
-                                        ka_notify_ticket_action_cb,
-                                        self,
-                                        NULL);
-    } else {
-        if (!self->priv->ns_persistence) {
-            notify_notification_add_action (notification,
-                                            "dont-show-again",
-                                            _("Don't show me this again"),
-                                            (NotifyActionCallback)
-                                            ka_notify_disable_action_cb, self,
-                                            NULL);
-        } else {
-            notify_notification_add_action (notification,
-                                        "ka-remove-ccache",
-                                        _("Remove Credentials Cache"),
-                                        (NotifyActionCallback)
-                                        ka_notify_ticket_action_cb,
-                                        self,
-                                        NULL);
-        }
-    }
-    ka_show_notification (self);
+    g_application_send_notification (G_APPLICATION (self),
+                                     PACKAGE,
+                                     notification);
 }
 
 
-static void
-ka_update_tray_icon (KaApplet *self, const char *icon, const char *tooltip)
-{
-    if (self->priv->tray_icon) {
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-        gtk_status_icon_set_from_icon_name (self->priv->tray_icon, icon);
-        gtk_status_icon_set_tooltip_text (self->priv->tray_icon, tooltip);
-G_GNUC_END_IGNORE_DEPRECATIONS
-    }
-}
-
 /* check whether a given notification is enabled */
 static gboolean
 get_notify_enabled (KaApplet *self, const char *key)
@@ -912,7 +656,6 @@ ka_applet_update_status (KaApplet *applet, krb5_timestamp expiry)
     static gboolean initial_notification = TRUE;
     static krb5_timestamp old_expiry = 0;
     gboolean notify = TRUE;
-    const char *status_icon = ka_applet_select_icon (applet, remaining);
     char *tooltip_text = ka_applet_tooltip_text (remaining);
 
     if (remaining > 0) {
@@ -979,106 +722,12 @@ ka_applet_update_status (KaApplet *applet, krb5_timestamp expiry)
     }
 
     old_expiry = expiry;
-    ka_update_tray_icon(applet, status_icon, tooltip_text);
     g_free (tooltip_text);
     initial_notification = FALSE;
     return 0;
 }
 
 
-static GActionEntry trayicon_entries[] = {
-    { "remove_credentials_cache", action_remove_credentials_cache, NULL, NULL, NULL, {0} },
-    { "list_tickets", action_list_tickets, NULL, NULL, NULL, {0} },
-    { "preferences", action_preferences, NULL, NULL, NULL, {0} },
-    { "about", action_about, NULL, NULL, NULL, {0} },
-    { "help", action_help, NULL, NULL, NULL, {0} },
-    { "quit", action_quit, NULL, NULL, NULL, {0} },
-};
-
-/* The tray icon's context menu */
-static gboolean
-ka_applet_create_tray_icon_context_menu (KaApplet *self)
-{
-    GtkBuilder *builder;
-    GMenuModel *model;
-    GSimpleActionGroup *group;
-
-    builder = gtk_builder_new_from_resource (
-        "/org/gnome/krb5-auth-dialog/ui/tray-icon-menu.ui");
-    model = G_MENU_MODEL (
-        gtk_builder_get_object (builder, "tray-icon-context-menu"));
-
-    self->priv->context_menu = gtk_menu_new_from_model (model);
-    gtk_widget_show_all (self->priv->context_menu);
-
-    group = g_simple_action_group_new ();
-    g_action_map_add_action_entries (G_ACTION_MAP (group),
-                                     trayicon_entries, G_N_ELEMENTS (trayicon_entries),
-                                     self);
-
-    gtk_widget_insert_action_group (GTK_WIDGET(self->priv->context_menu),
-                                    "trayicon",
-                                    G_ACTION_GROUP(group));
-
-    g_object_unref (builder);
-    return TRUE;
-}
-
-
-static void
-ka_tray_icon_on_menu (GtkStatusIcon *status_icon G_GNUC_UNUSED,
-                      guint button,
-                      guint activate_time,
-                      gpointer user_data)
-{
-    KaApplet *applet = KA_APPLET (user_data);
-
-    KA_DEBUG ("Trayicon right clicked: %d", applet->priv->pw_prompt_secs);
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-    gtk_menu_popup (GTK_MENU (applet->priv->context_menu), NULL, NULL,
-                    gtk_status_icon_position_menu, applet->priv->tray_icon,
-                    button, activate_time);
-G_GNUC_END_IGNORE_DEPRECATIONS
-}
-
-
-static gboolean
-ka_tray_icon_on_click (GtkStatusIcon *status_icon G_GNUC_UNUSED,
-                       gpointer data)
-{
-    KaApplet *applet = KA_APPLET (data);
-
-    KA_DEBUG ("Trayicon clicked: %d", applet->priv->pw_prompt_secs);
-    ka_grab_credentials (applet);
-    return TRUE;
-}
-
-
-static gboolean
-ka_applet_create_tray_icon (KaApplet *self)
-{
-    GtkStatusIcon *tray_icon;
-
-    if (self->priv->ns_persistence)
-        return FALSE;
-
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-    tray_icon = self->priv->tray_icon = gtk_status_icon_new ();
-    gtk_status_icon_set_from_icon_name (tray_icon,
-                                        self->priv->icons[exp_icon]);
-    gtk_status_icon_set_tooltip_text (tray_icon, PACKAGE);
-    gtk_status_icon_set_title (tray_icon, KA_NAME);
-G_GNUC_END_IGNORE_DEPRECATIONS
-
-    g_signal_connect (G_OBJECT (tray_icon), "activate",
-                      G_CALLBACK (ka_tray_icon_on_click), self);
-    g_signal_connect (G_OBJECT (tray_icon),
-                      "popup-menu",
-                      G_CALLBACK (ka_tray_icon_on_menu), self);
-    ka_applet_create_tray_icon_context_menu (self);
-    return TRUE;
-}
-
 static int
 ka_applet_setup_icons (KaApplet *applet)
 {
@@ -1145,43 +794,6 @@ ka_applet_signal_emit (KaApplet *this,
 }
 
 
-static void
-ka_ns_check_persistence (KaApplet *self)
-{
-    GList   *caps;
-    GList   *l;
-    gboolean is_autostart = g_getenv("DESKTOP_AUTOSTART_ID") ? TRUE : FALSE;
-    gint    seconds = 5;
-
-    self->priv->ns_persistence = FALSE;
-
-    if (self->priv->debug_flags & KA_DEBUG_NO_PERSISTENCE)
-        return;
-
-    do {
-        caps = notify_get_server_caps ();
-        if (caps == NULL)
-            g_warning ("Failed to read server caps");
-        else {
-            l = g_list_find_custom (caps, "persistence", (GCompareFunc)strcmp);
-            if (l != NULL) {
-                self->priv->ns_persistence = TRUE;
-                KA_DEBUG ("Notification server supports persistence.");
-            }
-            g_list_foreach (caps, (GFunc) g_free, NULL);
-            g_list_free (caps);
-        }
-        /* During session start we have to wait until the shell is fully up
-         * to reliably detect the persistence property (#642666) */
-        if (is_autostart && !self->priv->ns_persistence) {
-            sleep(1);
-            seconds--;
-        } else
-            break;
-    } while (seconds);
-}
-
-
 /* undo what was done on startup() */
 void
 ka_applet_destroy (KaApplet* self)
@@ -1199,23 +811,15 @@ ka_applet_destroy (KaApplet* self)
     gtk_widget_destroy (GTK_WIDGET(self->priv->prefs));
     self->priv->prefs = NULL;
 
-    if (self->priv->context_menu) {
-        gtk_widget_destroy (GTK_WIDGET(self->priv->context_menu));
-        self->priv->context_menu = NULL;
-    }
-
     ka_kerberos_destroy ();
 }
 
 
-/* create the tray icon applet */
 KaApplet *
-ka_applet_create ()
+ka_applet_create (void)
 {
     KaApplet *applet = ka_applet_new ();
 
-    ka_applet_handle_debug(applet);
-
     if (!(ka_applet_setup_icons (applet)))
         g_error ("Failure to setup icons");
     gtk_window_set_default_icon_name (applet->priv->icons[val_icon]);
@@ -1231,9 +835,6 @@ ka_applet_create ()
 
     g_return_val_if_fail (ka_dbus_connect (applet), NULL);
 
-    ka_ns_check_persistence(applet);
-    ka_applet_create_tray_icon (applet);
-
     return applet;
 }
 
@@ -1247,6 +848,7 @@ main (int argc, char *argv[])
     bind_textdomain_codeset (PACKAGE, "UTF-8");
     bindtextdomain (PACKAGE, LOCALE_DIR);
 
+    g_set_prgname (KA_APP_ID);
     g_set_application_name (KA_NAME);
 
     gtk_init (&argc, &argv);
