@@ -31,19 +31,12 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
-#include "secmem-util.h"
-#include "memory.h"
-
 #include "ka-kerberos.h"
 #include "ka-applet-priv.h"
 #include "ka-pwdialog.h"
 #include "ka-tools.h"
 #include "ka-main-window.h"
 
-#ifdef ENABLE_NETWORK_MANAGER
-# include <NetworkManager.h>
-#endif
-
 #ifdef HAVE_HX509_ERR_H
 #include <hx509_err.h>
 #endif
@@ -63,10 +56,6 @@ static int ka_renew_credentials (KaApplet *applet);
 static gboolean ka_get_tgt_from_ccache (krb5_context context,
                                         krb5_creds *creds);
 
-#ifdef ENABLE_NETWORK_MANAGER
-NMClient *nm_client;
-#endif
-
 /* YAY for different Kerberos implementations */
 static int
 get_cred_forwardable (krb5_creds *creds)
@@ -260,7 +249,7 @@ credentials_expiring_real (KaApplet *applet)
 
 /* time in seconds the tgt will be still valid */
 int
-ka_tgt_valid_seconds ()
+ka_tgt_valid_seconds (void)
 {
     krb5_timestamp now;
 
@@ -319,20 +308,12 @@ ka_get_service_tickets (GtkListStore * tickets, gboolean hide_conf_tickets)
     ret = krb5_cc_start_seq_get (kcontext, ccache, &cursor);
     if (ret == KRB5_FCC_NOFILE) {
         ka_log_error_message_at_level (G_LOG_LEVEL_INFO, "krb5_cc_start_seq_get", kcontext, ret);
-
-        gtk_list_store_append (tickets, &iter);
-        gtk_list_store_set (tickets, &iter,
-                            PRINCIPAL_COLUMN, _("Your ticket cache is currently empty"),
-                            FORWARDABLE_COLUMN, FALSE,
-                            RENEWABLE_COLUMN, FALSE,
-                            PROXIABLE_COLUMN, FALSE, -1);
         retval = TRUE;
         goto out;
     } else if (ret) {
         goto out;
     }
 
-
     while ((ret = krb5_cc_next_cred (kcontext, ccache, &cursor, &creds)) == 0) {
         gboolean renewable, proxiable, forwardable;
 
@@ -483,36 +464,18 @@ auth_dialog_prompter (krb5_context ctx G_GNUC_UNUSED,
 }
 
 
-#ifdef ENABLE_NETWORK_MANAGER
 static void
-ka_nm_client_state_changed_cb (NMClient * client,
-                               GParamSpec *pspec G_GNUC_UNUSED, gpointer data)
+ka_network_available_changed_cb (GNetworkMonitor *mon,
+                                 GParamSpec *pspec G_GNUC_UNUSED,
+                                 gpointer data)
 {
-    NMState state;
     gboolean *online = (gboolean *) data;
 
-    state = nm_client_get_state (client);
-    switch (state) {
-    case NM_STATE_UNKNOWN:
-    case NM_STATE_ASLEEP:
-    case NM_STATE_CONNECTING:
-        KA_DEBUG ("Network state: %d", state);
-        /* do nothing */
-        break;
-    case NM_STATE_DISCONNECTING:
-    case NM_STATE_DISCONNECTED:
-        KA_DEBUG ("Network disconnected");
-        *online = FALSE;
-        break;
-    case NM_STATE_CONNECTED_LOCAL:
-    case NM_STATE_CONNECTED_SITE:
-    case NM_STATE_CONNECTED_GLOBAL:
-        KA_DEBUG ("Network connected");
-        *online = TRUE;
-        break;
-    }
+    /* TODO: better bind to a property */
+    *online = g_network_monitor_get_network_available (mon);
+    KA_DEBUG ("Network state: %sline", *online ? "on" : "off");
 }
-#endif
+
 
 /* credentials expiring timer */
 static gboolean
@@ -670,7 +633,7 @@ ka_parse_name (KaApplet *applet, krb5_context krbcontext,
  * caller needs to free the returned result using g_free();
  */
 char *
-ka_unparse_name ()
+ka_unparse_name (void)
 {
     char *princ, *gprinc = NULL;
     krb5_error_code err;
@@ -700,13 +663,21 @@ ccache_changed_cb (GFileMonitor *monitor G_GNUC_UNUSED,
     gchar *ccache_name = g_file_get_path (file);
 
     switch (event_type) {
-    case G_FILE_MONITOR_EVENT_DELETED:
-    case G_FILE_MONITOR_EVENT_CREATED:
     case G_FILE_MONITOR_EVENT_CHANGED:
+    case G_FILE_MONITOR_EVENT_CREATED:
+    case G_FILE_MONITOR_EVENT_DELETED:
+    case G_FILE_MONITOR_EVENT_MOVED:
+    case G_FILE_MONITOR_EVENT_RENAMED:
         KA_DEBUG ("%s changed", ccache_name);
         credentials_expiring ((gpointer) applet);
         g_signal_emit_by_name(applet, "krb-ccache-changed");
         break;
+    case G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED:
+    case G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT:
+    case G_FILE_MONITOR_EVENT_MOVED_IN:
+    case G_FILE_MONITOR_EVENT_MOVED_OUT:
+    case G_FILE_MONITOR_EVENT_PRE_UNMOUNT:
+    case G_FILE_MONITOR_EVENT_UNMOUNTED:
     default:
         KA_DEBUG ("%s unhandled event: %d", ccache_name, event_type);
     }
@@ -770,7 +741,7 @@ grab_credentials (KaApplet *applet)
 
     g_object_get (applet, KA_PROP_NAME_PK_USERID, &pk_userid,
                   "pk-anchors", &pk_anchors, NULL);
-#if ENABLE_PKINIT && HAVE_HX509_ERR_H && HAVE_KRB5_GET_INIT_CREDS_OPT_SET_PKINIT
+#if ENABLE_PKINIT && defined(HAVE_HX509_ERR_H) && HAVE_KRB5_GET_INIT_CREDS_OPT_SET_PKINIT
     /* pk_userid set: try pkinit */
     if (pk_userid && strlen (pk_userid)) {
         retval = ka_auth_heimdal_pkinit (applet, &my_creds,
@@ -915,7 +886,7 @@ ka_get_tgt_from_ccache (krb5_context context, krb5_creds *creds)
 }
 
 static gboolean
-ka_krb5_context_init ()
+ka_krb5_context_init (void)
 {
     krb5_error_code err;
     gboolean have_tgt = FALSE;
@@ -937,7 +908,7 @@ ka_krb5_context_init ()
 
 
 static gboolean
-ka_krb5_context_free ()
+ka_krb5_context_free (void)
 {
     if (kcontext_valid) {
         kcontext_valid = FALSE;
@@ -1057,50 +1028,15 @@ ka_grab_credentials (KaApplet *applet)
 
 
 static void
-ka_secmem_init (void)
-{
-    /* Initialize secure memory.  1 is too small, so the default size
-       will be used.  */
-    secmem_init (1);
-    secmem_set_flags (SECMEM_WARN);
-    drop_privs ();
-
-    if (atexit (secmem_term))
-        g_error ("Couln't register atexit handler");
-}
-
-
-static void
-ka_nm_shutdown (void)
-{
-#ifdef ENABLE_NETWORK_MANAGER
-    if (nm_client) {
-        g_object_unref (nm_client);
-        nm_client = NULL;
-    }
-#endif
-}
-
-
-static gboolean
 ka_nm_init (void)
 {
-#ifdef ENABLE_NETWORK_MANAGER
-    GError *error = NULL;
+    GNetworkMonitor *mon = g_network_monitor_get_default ();
 
-    nm_client = nm_client_new (NULL, &error);
-    if (!nm_client) {
-        g_warning ("Could not initialize nm-client: %s", error->message);
-        g_error_free (error);
-        return FALSE;
-    }
-    g_signal_connect (nm_client, "notify::state",
-                      G_CALLBACK (ka_nm_client_state_changed_cb),
+    g_signal_connect (mon, "notify::network-available",
+                      G_CALLBACK (ka_network_available_changed_cb),
                       &is_online);
     /* Set initial state */
-    ka_nm_client_state_changed_cb (nm_client, NULL, &is_online);
-#endif /* ENABLE_NETWORK_MANAGER */
-    return TRUE;
+    ka_network_available_changed_cb (mon, NULL, &is_online);
 }
 
 
@@ -1109,7 +1045,6 @@ ka_kerberos_init (KaApplet *applet)
 {
     gboolean ret;
 
-    ka_secmem_init ();
     ret = ka_krb5_context_init ();
     ka_nm_init ();
     g_timeout_add_seconds (CREDENTIAL_CHECK_INTERVAL,
@@ -1121,10 +1056,8 @@ ka_kerberos_init (KaApplet *applet)
 
 
 gboolean
-ka_kerberos_destroy ()
+ka_kerberos_destroy (void)
 {
-    ka_nm_shutdown ();
-
     if (ccache_monitor)
         g_object_unref (ccache_monitor);
 
