@@ -65,11 +65,36 @@ ticket_btn_clicked(GtkButton* btn G_GNUC_UNUSED, gpointer user_data)
 }
 
 
+static void
+on_row_inserted(GtkTreeModel *model,
+                GtkTreePath  *unused,
+                GtkTreeIter  *iter,
+                GtkStack     *stack)
+{
+    gtk_stack_set_visible_child_name(stack, "tickets");
+}
+
+
+static void
+on_row_deleted(GtkTreeModel *model,
+               GtkTreePath  *unused,
+               GtkStack     *stack)
+{
+    GtkTreeIter iter;
+
+    if (!gtk_tree_model_get_iter_first(model, &iter))
+        gtk_stack_set_visible_child_name(stack, "message");
+}
+
+
+
 GtkApplicationWindow *
 ka_main_window_create (KaApplet *applet)
 {
     GtkCellRenderer *text_renderer, *toggle_renderer;
+    GtkTreeViewColumn *column;
     GtkTreeView *tickets_view;
+    GtkStack *stack;
     GtkBuilder *builder;
 
     tickets = gtk_list_store_new (N_COLUMNS,
@@ -92,6 +117,9 @@ ka_main_window_create (KaApplet *applet)
                              GTK_TREE_MODEL (tickets));
 
     text_renderer = gtk_cell_renderer_text_new ();
+    g_object_set (text_renderer,
+                  "ellipsize", PANGO_ELLIPSIZE_MIDDLE,
+                  NULL);
     toggle_renderer = gtk_cell_renderer_toggle_new ();
 
     gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(tickets_view), -1,
@@ -101,13 +129,13 @@ ka_main_window_create (KaApplet *applet)
                                                 PRINCIPAL_COLUMN,
                                                 NULL);
     gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(tickets_view), -1,
-                                                _("Start Time"),
+                                                _("Start"),
                                                 text_renderer,
                                                 "text",
                                                 START_TIME_COLUMN,
                                                 NULL);
     gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(tickets_view), -1,
-                                                _("End Time"),
+                                                _("End"),
                                                 text_renderer,
                                                 "markup",
                                                 END_TIME_COLUMN,
@@ -134,6 +162,20 @@ ka_main_window_create (KaApplet *applet)
                                                 RENEWABLE_COLUMN,
                                                 NULL);
 
+    for (int i = PRINCIPAL_COLUMN; i <= END_TIME_COLUMN; i++) {
+        column = gtk_tree_view_get_column(tickets_view, i);
+        g_object_set (column, "expand", TRUE, NULL);
+    }
+
+    stack = GTK_STACK (gtk_builder_get_object (builder, "stack"));
+    g_signal_connect(tickets, "row-inserted",
+                     G_CALLBACK(on_row_inserted),
+                     stack);
+    g_signal_connect(tickets, "row-deleted",
+                     G_CALLBACK(on_row_deleted),
+                     stack);
+    on_row_deleted(GTK_TREE_MODEL(tickets), NULL, stack);
+
     g_signal_connect (applet, "krb-ccache-changed",
                       G_CALLBACK(ccache_changed_cb),
                       NULL);
@@ -179,7 +221,7 @@ ka_main_window_show (KaApplet *applet)
 }
 
 void
-ka_main_window_hide ()
+ka_main_window_hide (void)
 {
     KA_DEBUG("Hiding main window");
     gtk_widget_hide (GTK_WIDGET(main_window));
